# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/internal_redirect/safe_cross_scheme/v3/safe_cross_scheme_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVenvoy/extensions/internal_redirect/safe_cross_scheme/v3/safe_cross_scheme_config.proto\x12\x37\x65nvoy.extensions.internal_redirect.safe_cross_scheme.v3\x1a\x1dudpa/annotations/status.proto\"\x17\n\x15SafeCrossSchemeConfigB\xe1\x01\nEio.envoyproxy.envoy.extensions.internal_redirect.safe_cross_scheme.v3B\x1aSafeCrossSchemeConfigProtoP\x01Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/internal_redirect/safe_cross_scheme/v3;safe_cross_schemev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.internal_redirect.safe_cross_scheme.v3.safe_cross_scheme_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEio.envoyproxy.envoy.extensions.internal_redirect.safe_cross_scheme.v3B\032SafeCrossSchemeConfigProtoP\001Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/internal_redirect/safe_cross_scheme/v3;safe_cross_schemev3\272\200\310\321\006\002\020\002'
  _globals['_SAFECROSSSCHEMECONFIG']._serialized_start=178
  _globals['_SAFECROSSSCHEMECONFIG']._serialized_end=201
# @@protoc_insertion_point(module_scope)
